@@ -22,6 +22,10 @@ selfmon=True
 
 exe and name are both lists of comma-separated regexps.
 
+count_workers defined under [process] will determine whether to count how many
+workers are there of processes which match this [process],
+for example: cgi workers.
+
 cpu_interval is the interval in seconds used to calculate cpu usage percentage.
 From psutil's docs:
 
@@ -133,7 +137,8 @@ calls."""),
                     proc[key] = [proc[key]]
                 proc[key] = [re.compile(e) for e in proc[key]]
             proc['selfmon'] = cfg.get('selfmon', '').lower() == 'true'
-            proc['count_workers'] = cfg.get('count_workers', '').lower() == 'true'
+            proc['count_workers'] = cfg.get(
+                'count_workers', '').lower() == 'true'
             self.processes[process] = proc
 
     def filter_processes(self):
@@ -178,31 +183,35 @@ calls."""),
             self.log.error('No process resource metrics retrieved')
             return None
 
-        self.setup_config()
-        self.filter_processes()
-        unit = self.config['unit']
-        for process, cfg in self.processes.items():
-            # finally publish the results for each process group
-            metric_name = "%s.rss" % process
-            metric_value = diamond.convertor.binary.convert(
-                sum(p.rss for p in cfg['procs']),
-                oldUnit='byte', newUnit=unit)
-            # Publish Metric
-            self.publish(metric_name, metric_value)
-
-            metric_name = "%s.vms" % process
-            metric_value = diamond.convertor.binary.convert(
-                sum(p.vms for p in cfg['procs']),
-                oldUnit='byte', newUnit=unit)
-            # Publish Metric
-            self.publish(metric_name, metric_value)
-
-            # CPU percent
-            metric_name = "%s.cpu_percent" % process
-            metric_value = sum(p.cpu_percent for p in cfg['procs'])
-            # Publish Metric
-            self.publish(metric_name, metric_value)
-            if cfg['count_workers']:
-                metric_name = '%s.workers' % process
-                metric_value = len(cfg['procs'])
+        try:
+            self.setup_config()
+            self.filter_processes()
+            unit = self.config['unit']
+            for process, cfg in self.processes.items():
+                # finally publish the results for each process group
+                metric_name = "%s.rss" % process
+                metric_value = diamond.convertor.binary.convert(
+                    sum(p.rss for p in cfg['procs']),
+                    oldUnit='byte', newUnit=unit)
+                # Publish Metric
                 self.publish(metric_name, metric_value)
+
+                metric_name = "%s.vms" % process
+                metric_value = diamond.convertor.binary.convert(
+                    sum(p.vms for p in cfg['procs']),
+                    oldUnit='byte', newUnit=unit)
+                # Publish Metric
+                self.publish(metric_name, metric_value)
+
+                # CPU percent
+                metric_name = "%s.cpu_percent" % process
+                metric_value = sum(p.cpu_percent for p in cfg['procs'])
+                # Publish Metric
+                self.publish(metric_name, metric_value)
+
+                if cfg['count_workers']:
+                    metric_name = '%s.workers' % process
+                    metric_value = len(cfg['procs'])
+                    self.publish(metric_name, metric_value)
+        except Exception, e:
+            self.log.error(str(e))
